#include <bits/stdc++.h>
using namespace std;

// Faster replacement for cin and cout. It was heavily inspired (almost
// copy-pasted) from:
//  https://discuss.codechef.com/questions/6677/cool-fast-io-implementation
//  http://ideone.com/fOK6CW
//
// Everything works as if cin/cout were used, but instead of std::cin, std::cout
// the optimized classes FastInput/FastOutput are called.
// With floating point types this classes behave exactly as cin/cout.
//
// Performances:
//  Summary: Reading integers is much faster.
//
//  In any case these are faster than standard cin/cout.
//  For int/int64 FastInput is 66% faster than cin.
//  For double and strings the speed is the same
//  For int/int64 FastOutput is 30% faster than cout.
//  For strings it is slightly faster, for anything else is the same.  
 
#include <string>
#include <cstdlib>
using namespace std;
 
// Replacement for cin.
// The >> operator is implemented optimizing it for integer types and strings.
class FastInput {
  public:
    // Various specializations of >>.
    FastInput& operator >> (char& c) {
        c = NextChar();
        return *this;
    }
 
    FastInput& operator >> (char* str) {
        if (SkipBlanks()) {
            if (PeekChar()) {
                *(str++) = PeekChar();
                while (!IsBlank(NextChar())) *(str++) = PeekChar();
            }
            *(str++) = 0;
        }
        return *this;
    }
 
    FastInput& operator >> (string& str) {
        if (SkipBlanks()) {
            str.clear();
            str += PeekChar();
            while (!IsBlank(NextChar())) str += PeekChar();
        }
        return *this;
    }
 
    FastInput& operator >> (double& d) {
        static char buffer[1<<10];
        if ((*this) >> buffer) sscanf(buffer, "%lf", &d);
        return *this;
    }
 
    template <typename intType>
    FastInput& operator >> (intType& n) {
        if (SkipBlanks()) {
            int sign = +1;
            if (PeekChar() == '-') {
                sign = -1;
                n = NextChar() - '0';
            } else
                n = PeekChar() - '0';
            while (!IsBlank(NextChar())) {
                n += n + (n << 3) + PeekChar() - 48;
            }
            n *= sign;
        }
        return *this;
    }
 
    // The empty method tie is useful to ignore calls to cin.tie(0).
    void tie(void*) {}
 
  private:
    // Low level methods.
    char cur;
    char NextChar() {
        #ifdef _WIN32
            return cur = _getchar_nolock();
        #else
            return cur = getc_unlocked(stdin);
        #endif
    }
    char PeekChar() { return cur; }
 
    // Input routines.
    operator bool() {
        return PeekChar();
    }
 
    static bool IsBlank(char c) {
        // 10 9 32 are ascii numbers for \n, \t, space.
        return (c <= 32 && c);
    }
 
    bool SkipBlanks() {
        while (IsBlank(NextChar()));
        return PeekChar() != 0;
    }
} __fast_input__;
 
// Replacement for cout.
// The << operator is implemented optimizing it for integer types and strings.
class FastOutput {
  public:
    // Various specializations of <<.
    FastOutput& operator << (char c) {
        PutChar(c);
        return *this;
    }
    
    FastOutput& operator << (const char * s) {
        while (*s) PutChar(*s++);
        return *this;
    }
    
    FastOutput& operator << (const string & s) {
        for (char c : s) PutChar(c);
        return *this;
    }
    
    FastOutput& operator << (double d) {
        return (*this) << ToString(d);
    }
    
    template <typename intType>
    FastOutput& operator << (intType n) {
        return (*this) << ToString(n);
    }
  private:
    // Low level methods.
    void PutChar(char c) {
        #ifdef _WIN32
            _putchar_nolock(c);
        #else
            putc_unlocked(c, stdout);
        #endif
    }
 
    // ToString routines.
    const char* ToString(double d) {
        static char buffer[1<<6];
        sprintf(buffer, "%lf%c", d, '\0');
        return buffer;
    }
 
    template <typename intType>
    const char * ToString(intType n) {
        static char buffer[1<<6];
        char* p = (buffer + 30);
        if (n) {
            bool is_neg = 0;
            if (n < 0) {
                is_neg = 1;
                n = -n;
            }
            while (n) {
                *--p = (n % 10) + '0';
                n /= 10;
            }
            if (is_neg) *--p = '-';
        } else *--p = '0';
        return p;
    }
} __fast_output__;
 
// Defines replacing cin/cout with FastInput/FastOutput.
#undef cin  // To ignore reading from input.txt on local machine?
#define cin __fast_input__
#define cout __fast_output__
 
using namespace std;

const int N2 = 500000 + 1;
const int N = 2*N2;
int P[N];
int V[N];
int cnt[N];
 

int main() {
    ios::sync_with_stdio(false);
    cin.tie(0);
    
    int n;
    cin >> n;
    for (int i = 2; i <= n; ++i) cin >> P[i];
    
    for (int v = n; v >= 1; v--) {
        V[v]++;
        V[P[v]] += V[v];
    }
    int centroid = 1;
    for (int v = 2; v <= n; v++) if (2*V[v] >= n) centroid = v;

    int bef = 0;
    int v = centroid;
    while (v) {
        swap(bef, V[v]);
        V[v] = n - V[v];
        v = P[v];
    }
    if (P[centroid]) cnt[V[P[centroid]]]++;
    for (int v = 2; v <= n; v++) if (P[v] == centroid) cnt[V[v]]++;
        
    vector<int> S;
    for (int x = 1; x <= n; x++) {
        while (cnt[x] >= 3) {
            cnt[2*x]++;
            cnt[x] -= 2;
        }
        for (int i = 0; i < cnt[x]; i++) S.push_back(x);
    }

    vector<int> M(N2, 0);
    M[0] = 1;
    long long res = 0;
    for (int v = 1; v <= n; v++) res += V[v];


    // if (((long long)S.size()) * N2 > 3e8) { // This cheap trick must get WA
        // int g = 0;
        // for (int val: S) g = __gcd(g, val);
        // for (int i = n/2; i >= 0; i--) if (i%g == 0) M[i] = true;
    // } else {
    int sum = 0;
    for (int val : S) {
        sum += val;
        for (int i = min(N2-1, sum); i >= val; i--) M[i] = M[i] | M[i-val];
        if (M[n/2]) break;
    }
    // }

    for (int i = n/2; i >= 0; --i) {
        if (M[i]) {
            res += ((long long)i) * (n-1-i);
            break;
        }
    }
 
    cout << res << "\n";
}
