#define _USE_MATH_DEFINES
#include <bits/stdc++.h>
using namespace std;
// Precomputes the vectors rev and roots as required by the function FFT.
// It is called internally by FFT when necessary (i.e., when the length of
// the vector is strictly larger than all previous calls to FFT).
// Both the arrays rev and roots have length N. Their values satisfy:
// - rev[i] is the bit-reverse of i.
// - roots contains the roots of unity. For any k that is a power of two,
//   and any i < k, roots[k + i] contains the i-th power of the (2k)-root of
//   unity. Using such an array speeds up (and simplifies) the code.
//
// Complexity: O(N)
//
// Assumptions:
//  1. The type T is either complex<double> or ModularInteger.
//  2. N power of 2
//  3. If T = ModularInteger, then ModularInteger::mod is prime and
//     N | mod-1 .
template <typename T>
void _FFT_Precompute(int N, vector<int>& rev, vector<T>& roots) {
    assert(N > 0 and !(N&(N-1)));
    rev.resize(N);
    roots.resize(N);
    rev[0] = 0;
    for (int i = 1; i < N; i++) rev[i] = (rev[i>>1]>>1) ^ ((i&1)?(N>>1):0);
    
    for (int k = 1; k < N; k<<=1) {
        for (int i = 0; i < k; i++) {
            double theta = M_PI*i/k;
            roots[k+i] = cos(theta) + 1i * sin(theta);
        }
    }
}

// Given a sequence of numbers, computes its discrete Fourier transform in-place.
// If inverse=true then the inverse of the Fourier transform is computed.
//
// More precisely, the resulting array a' satisfies
//  a'_i = \sum a_j w^{ij} ,
// where w is an N-root of unity (N = a.size()).
//
// Complexity: O(Nlog(N)) where N = a.size().
//
// Assumptions:
//  1. The type T is either complex<double> or ModularInteger.
//  2. The length of a is a power of 2.
//  3. If T = ModularInteger, then ModularInteger::mod is prime and the
//     length of a divides mod-1 .
template <typename T>
void FFT(vector<T>& a, bool inverse=false) {
    static vector<int> rev;
    static vector<T> roots;
    int N = a.size();
    assert(N > 0 and !(N&(N-1)));
    if ((int)rev.size() < N) _FFT_Precompute(N, rev, roots);

    int offset = 0;
    while ((1<<offset) < (int)rev.size()/N) offset++;

    for (int i = 0; i < N; i++) if (i < (rev[i]>>offset)) {
        swap(a[i], a[rev[i]>>offset]);
    }
    
    for (int k = 1; k < N; k<<=1) {
        for (int i = 0; i < N; i+=2*k) {
            for (int j = 0; j < k; j++) {
                T x = a[i+j], y = a[i+k+j] * roots[k+j];
                a[i+j] = x + y;
                a[i+k+j] = x - y;
            }
        }
    }

    if (inverse) {
        reverse(a.begin()+1, a.end());
        T invN = static_cast<T>(1) / static_cast<T>(N);
        for (auto& val : a) val *= invN;
    }
}


// Computes the convolution between a and b in O(n log n) where
// n = a.size() + b.size().
// It returns a vector c such that
//   c[k] = \sum_{i+j = k} a[i] b[j].
//
// Assumption: a and b are nonempty.
template<typename T>
vector<T> Convolution(vector<T> a, vector<T> b) {
    const static int small_len = 64;
    int alen = a.size(), blen = b.size();
    assert(1 <= alen and 1 <= blen);

    // Naive convolution O(alen * blen).
    // Used if one of the two vectors is very short.
    if (alen < small_len or blen < small_len) {
        vector<T> c(alen + blen-1, 0);
        for (int i = 0; i < alen; i++) for (int j = 0; j < blen; j++)
            c[i + j] += a[i] * b[j];
        return c;
    }
    
    int sz = 1;
    while (sz < alen + blen - 1) sz *= 2;
    a.resize(sz, 0);
    b.resize(sz, 0);
    FFT(a);
    FFT(b);
    for (int i = 0; i < sz; i++) a[i] *= b[i];
    FFT(a, true);
    a.resize(alen + blen - 1);
    return a;
}

const int N2 = 500000 + 1;
const int N = 2*N2;
int P[N];
int V[N];


typedef vector<bool> vb;
struct cmp_length {
    bool operator()(vb& A, vb& B) { return A.size() > B.size(); }
};

vb multiply(vb& A, vb& B) {
    vector<complex<double>> AA(A.size());
    vector<complex<double>> BB(B.size());
    for (int i = 0; i < (int)A.size(); i++) AA[i] = A[i];
    for (int i = 0; i < (int)B.size(); i++) BB[i] = B[i];
    vector<complex<double>> CC = Convolution(AA, BB);
    vb C(CC.size(), 0);
    for (int i = 0; i < (int)CC.size(); i++) if (CC[i].real() > 0.5) C[i] = 1;
    return C;
}
 

int main() {
    ios::sync_with_stdio(false);
    cin.tie(0);
    
    int n;
    cin >> n;
    for (int i = 2; i <= n; ++i) cin >> P[i];
    
    for (int v = n; v >= 1; v--) {
        V[v]++;
        V[P[v]] += V[v];
    }
    int centroid = 1;
    for (int v = 2; v <= n; v++) if (2*V[v] >= n) centroid = v;

    int bef = 0;
    int v = centroid;
    while (v) {
        swap(bef, V[v]);
        V[v] = n - V[v];
        v = P[v];
    }

    vector<int> Z;
    if (P[centroid]) Z.push_back(V[P[centroid]]);
    for (int v = 2; v <= n; v++) if (P[v] == centroid) Z.push_back(V[v]);

    // auto cmp_length = [](vb& A, vb& B) { return A.size() > B.size(); };
    priority_queue<vb, vector<vb>, cmp_length> q;
    for (int z: Z) {
        vb vec(z+1, false);
        vec[0] = vec[z] = true;
        q.push(vec);
    }

    while (q.size() >= 2) {
        vb A = q.top();
        q.pop();
        vb B = q.top();
        q.pop();
        q.push(multiply(A, B));
    }

    vb M = q.top();
 
    long long res = 0;
    for (int i = n/2; i >= 0; --i) {
        if (M[i]) {
            res = ((long long)i) * (n-1-i);
            break;
        }
    }
    
    for (int v = 1; v <= n; v++) res += V[v];
 
    cout << res << "\n";
}
